@@ -9,12 +9,12 @@ Genome MCP - 优化版本：智能基因组数据访问
 - 进化生物学数据分析
 """
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 # 核心组件导出
 from .core import (
+    EnsemblClient,
     NCBIClient,
-    OrthoDBClient,
     ParsedQuery,
     QueryExecutor,
     QueryParser,
@@ -128,7 +128,7 @@ __all__ = [
     "QueryExecutor",
     "NCBIClient",
     "UniProtClient",
-    "OrthoDBClient",
+    "EnsemblClient",
     "ParsedQuery",
     "QueryType",
     "_query_executor",
