@@ -5,7 +5,8 @@
 提供客户端、查询解析器、执行器和工具函数
 """
 
-from .clients import NCBIClient, OrthoDBClient, UniProtClient
+from .clients import NCBIClient, UniProtClient
+from .ensembl_client import EnsemblClient
 from .evolution_tools import analyze_gene_evolution, build_phylogenetic_profile
 from .query_executor import QueryExecutor
 from .query_parser import ParsedQuery, QueryParser, QueryType
@@ -14,7 +15,7 @@ __all__ = [
     # 客户端
     "NCBIClient",
     "UniProtClient",
-    "OrthoDBClient",
+    "EnsemblClient",
     # 查询相关
     "QueryParser",
     "QueryType",
